@@ -1,4 +1,5 @@
 
+from .errors import ScriptNotFoundError
 from .registry import Component, get_script
 from .util import autofill_args
 
@@ -9,12 +10,17 @@ prt = get_printer(__name__)
 
 @Component('run_mode/default')
 class Run_Mode:
+	'''
+	Run modes are used to actually execute the script specified by the user in the run command.
+	
+	It is recommended to register all run_modes with a ``run_mode/`` prefix, but not required.
+	'''
 	def __init__(self, A):
 		self.silent = A.pull('silent', True, silent=True)
 	
-	
 	@staticmethod
 	def get_script_info(script_name):
+		'''Given the name of the registered script, this returns the corresponding entry in the registry'''
 		return get_script(script_name)
 	
 	
@@ -30,6 +36,9 @@ class Run_Mode:
 		script_name = meta.pull('script_name', silent=self.silent)
 		script_info = self.get_script_info(script_name)
 		
+		if script_info is None:
+			raise ScriptNotFoundError(script_name)
+		
 		script_fn = script_info.fn
 		
 		if script_info.use_config:
